@@ -1,4 +1,5 @@
 """Example using zmq with asyncio coroutines"""
+
 # Copyright (c) PyZMQ Developers.
 # This example is in the public domain (CC-0)
 
@@ -45,12 +46,10 @@ async def sender() -> None:
         await asyncio.sleep(1)
 
 
-asyncio.run(
-    asyncio.wait(
-        [
-            ping(),
-            receiver(),
-            sender(),
-        ]
-    )
-)
+async def main() -> None:
+    tasks = [asyncio.create_task(coroutine()) for coroutine in [ping, receiver, sender]]
+    await asyncio.wait(tasks)
+
+
+if __name__ == "__main__":
+    asyncio.run(main())
