@@ -1,4 +1,5 @@
 import time
+
 import zmq
 
 ctx = zmq.Context.instance()
@@ -12,13 +13,13 @@ radio.connect('udp://127.0.0.1:5556')
 
 for i in range(10):
     time.sleep(0.1)
-    radio.send(b'%03i' % i, group='numbers')
+    radio.send(f'{i:03}'.encode('ascii'), group='numbers')
     try:
         msg = dish.recv(copy=False)
     except zmq.Again:
         print('missed a message')
         continue
-    print("Received %s:%s" % (msg.group, msg.bytes.decode('utf8')))
+    print(f"Received {msg.group}:{msg.bytes.decode('utf8')}")
 
 dish.close()
 radio.close()
