@@ -1,4 +1,4 @@
-from typing import Optional
+from __future__ import annotations
 
 from gevent import spawn, spawn_later
 
@@ -10,13 +10,13 @@ ctx = zmq.Context()
 sock = ctx.socket(zmq.PUSH)
 sock.bind('ipc:///tmp/zmqtest')
 
-spawn(sock.send_pyobj, ('this', 'is', 'a', 'python', 'tuple'))
-spawn_later(1, sock.send_pyobj, {'hi': 1234})
+spawn(sock.send_json, ['this', 'is', 'a', 'list'])
+spawn_later(1, sock.send_json, {'hi': 1234})
 spawn_later(
-    2, sock.send_pyobj, ({'this': ['is a more complicated object', ':)']}, 42, 42, 42)
+    2, sock.send_json, ({'this': ['is a more complicated object', ':)']}, 42, 42, 42)
 )
-spawn_later(3, sock.send_pyobj, 'foobar')
-spawn_later(4, sock.send_pyobj, 'quit')
+spawn_later(3, sock.send_json, 'foobar')
+spawn_later(4, sock.send_json, 'quit')
 
 
 # client
@@ -27,14 +27,14 @@ sock.connect('ipc:///tmp/zmqtest')
 
 def get_objs(sock: zmq.Socket):
     while True:
-        o = sock.recv_pyobj()
-        print('received python object:', o)
+        o = sock.recv_json()
+        print('received:', o)
         if o == 'quit':
             print('exiting.')
             break
 
 
-def print_every(s: str, t: Optional[float] = None):
+def print_every(s: str, t: float | None = None):
     print(s)
     if t:
         spawn_later(t, print_every, s, t)
