@@ -76,6 +76,7 @@ from cython.cimports.libc.stdio import fprintf
 from cython.cimports.libc.stdio import stderr as cstderr
 from cython.cimports.libc.stdlib import free, malloc
 from cython.cimports.libc.string import memcpy
+from cython.cimports.zmq.backend.cython import libzmq
 from cython.cimports.zmq.backend.cython._externs import (
     get_ipc_path_max_len,
     getpid,
@@ -88,13 +89,16 @@ from cython.cimports.zmq.backend.cython.libzmq import (
     ZMQ_ENOTSOCK,
     ZMQ_ETERM,
     ZMQ_EVENT_ALL,
+    ZMQ_FD,
     ZMQ_IDENTITY,
     ZMQ_IO_THREADS,
     ZMQ_LINGER,
     ZMQ_POLLIN,
+    ZMQ_POLLOUT,
     ZMQ_RCVMORE,
     ZMQ_ROUTER,
     ZMQ_SNDMORE,
+    ZMQ_THREAD_SAFE,
     ZMQ_TYPE,
     _zmq_version,
     fd_t,
@@ -131,6 +135,10 @@ from cython.cimports.zmq.backend.cython.libzmq import (
     zmq_msg_set_routing_id,
     zmq_msg_size,
     zmq_msg_t,
+    zmq_poller_add,
+    zmq_poller_destroy,
+    zmq_poller_fd,
+    zmq_poller_new,
     zmq_pollitem_t,
     zmq_proxy,
     zmq_proxy_steerable,
@@ -156,6 +164,8 @@ from zmq.error import (
 
 IPC_PATH_MAX_LEN: int = get_ipc_path_max_len()
 
+PYZMQ_DRAFT_API: bool = bool(libzmq.PYZMQ_DRAFT_API)
+
 
 @cfunc
 @inline
@@ -659,11 +669,16 @@ class Context:
 
 @cfunc
 @inline
-def _c_addr(addr) -> p_char:
+def _c_addr(addr) -> bytes:
+    """cast an address input to bytes
+
+    Expects a str, but accepts bytes
+    and raises informative TypeError otherwise.
+    """
     if isinstance(addr, str):
-        addr = addr.encode('utf-8')
+        addr = addr.encode("utf-8")
     try:
-        c_addr: p_char = addr
+        c_addr: bytes = addr
     except TypeError:
         raise TypeError(f"Expected addr to be str, got addr={addr!r}")
     return c_addr
@@ -700,6 +715,7 @@ class Socket:
     ):
         # pre-init
         self.handle = NULL
+        self._draft_poller = NULL
         self._pid = 0
         self._shadow = False
         self.context = None
@@ -756,6 +772,12 @@ class Socket:
         if self.handle != NULL and not self._closed and getpid() == self._pid:
             if setlinger:
                 zmq_setsockopt(self.handle, ZMQ_LINGER, address(linger_c), sizeof(int))
+
+            # teardown draft poller
+            if self._draft_poller != NULL:
+                zmq_poller_destroy(address(self._draft_poller))
+                self._draft_poller = NULL
+
             rc = zmq_close(self.handle)
             if rc < 0 and _zmq_errno() != ENOTSOCK:
                 # ignore ENOTSOCK (closed by Context)
@@ -834,6 +856,10 @@ class Socket:
 
         See the 0MQ API documentation for details on specific options.
 
+        .. versionchanged:: 27
+            Added experimental support for ZMQ_FD for draft sockets via `zmq_poller_fd`.
+            Requires libzmq >=4.3.2 built with draft support.
+
         Parameters
         ----------
         option : int
@@ -882,11 +908,51 @@ class Socket:
                 self.handle, option, cast(p_void, address(optval_int64_c)), address(sz)
             )
             result = optval_int64_c
+        elif option == ZMQ_FD and self._draft_poller != NULL:
+            # draft sockets use FD of a draft zmq_poller as proxy
+            rc = zmq_poller_fd(self._draft_poller, address(optval_fd_c))
+            _check_rc(rc)
+            result = optval_fd_c
         elif opt_type == _OptType.fd:
             sz = sizeof(fd_t)
-            _getsockopt(
-                self.handle, option, cast(p_void, address(optval_fd_c)), address(sz)
-            )
+            try:
+                _getsockopt(
+                    self.handle, option, cast(p_void, address(optval_fd_c)), address(sz)
+                )
+            except ZMQError as e:
+                # threadsafe sockets don't support ZMQ_FD (yet!)
+                # fallback on zmq_poller_fd as proxy with the same behavior
+                # until libzmq fixes this.
+                # if upstream fixes it, this branch will never be taken
+                if (
+                    option == ZMQ_FD
+                    and e.errno == zmq.Errno.EINVAL
+                    and self.get(ZMQ_THREAD_SAFE)
+                ):
+                    _check_version(
+                        (4, 3, 2), "draft socket FD support via zmq_poller_fd"
+                    )
+                    if not zmq.DRAFT_API:
+                        raise RuntimeError(
+                            "libzmq and pyzmq must be built with draft support"
+                        )
+                    warnings.warn(zmq.error.DraftFDWarning(), stacklevel=2)
+
+                    # create a poller and retrieve its fd
+                    self._draft_poller = zmq_poller_new()
+                    if self._draft_poller == NULL:
+                        # failed (why?), raise original error
+                        raise
+                    # register self with poller
+                    rc = zmq_poller_add(
+                        self._draft_poller, self.handle, NULL, ZMQ_POLLIN | ZMQ_POLLOUT
+                    )
+                    _check_rc(rc)
+                    # use poller fd as proxy for ours
+                    rc = zmq_poller_fd(self._draft_poller, address(optval_fd_c))
+                    _check_rc(rc)
+                else:
+                    raise
             result = optval_fd_c
         else:
             # default is to assume int, which is what most new sockopts will be
@@ -918,7 +984,8 @@ class Socket:
             tcp, udp, pgm, epgm, inproc and ipc. If the address is unicode, it is
             encoded to utf-8 first.
         """
-        c_addr: p_char = _c_addr(addr)
+        _addr_bytes: bytes = _c_addr(addr)
+        c_addr: p_char = _addr_bytes
         _check_closed(self)
         rc: C.int = zmq_bind(self.handle, c_addr)
         if rc != 0:
@@ -959,7 +1026,8 @@ class Socket:
             encoded to utf-8 first.
         """
         rc: C.int
-        c_addr: p_char = _c_addr(addr)
+        _addr_bytes: bytes = _c_addr(addr)
+        c_addr: p_char = _addr_bytes
         _check_closed(self)
 
         while True:
@@ -987,7 +1055,8 @@ class Socket:
             tcp, udp, pgm, inproc and ipc. If the address is unicode, it is
             encoded to utf-8 first.
         """
-        c_addr: p_char = _c_addr(addr)
+        _addr_bytes: bytes = _c_addr(addr)
+        c_addr: p_char = _addr_bytes
         _check_closed(self)
         rc: C.int = zmq_unbind(self.handle, c_addr)
         if rc != 0:
@@ -1008,7 +1077,8 @@ class Socket:
             tcp, udp, pgm, inproc and ipc. If the address is unicode, it is
             encoded to utf-8 first.
         """
-        c_addr: p_char = _c_addr(addr)
+        _addr_bytes: bytes = _c_addr(addr)
+        c_addr: p_char = _addr_bytes
         _check_closed(self)
 
         rc: C.int = zmq_disconnect(self.handle, c_addr)
@@ -1038,7 +1108,8 @@ class Socket:
         """
         c_addr: p_char = NULL
         if addr is not None:
-            c_addr = _c_addr(addr)
+            _addr_bytes: bytes = _c_addr(addr)
+            c_addr: p_char = _addr_bytes
         _check_closed(self)
 
         _check_rc(zmq_socket_monitor(self.handle, c_addr, events))
@@ -1054,8 +1125,8 @@ class Socket:
         .. versionadded:: 17
         """
         _check_version((4, 2), "RADIO-DISH")
-        if not zmq.has('draft'):
-            raise RuntimeError("libzmq must be built with draft support")
+        if not zmq.DRAFT_API:
+            raise RuntimeError("libzmq and pyzmq must be built with draft support")
         if isinstance(group, str):
             group = group.encode('utf8')
         c_group: bytes = group
@@ -1073,8 +1144,8 @@ class Socket:
         .. versionadded:: 17
         """
         _check_version((4, 2), "RADIO-DISH")
-        if not zmq.has('draft'):
-            raise RuntimeError("libzmq must be built with draft support")
+        if not zmq.DRAFT_API:
+            raise RuntimeError("libzmq and pyzmq must be built with draft support")
         rc: C.int = zmq_leave(self.handle, group)
         _check_rc(rc)
 
@@ -1961,6 +2032,7 @@ def monitored_queue(
 
 __all__ = [
     'IPC_PATH_MAX_LEN',
+    'PYZMQ_DRAFT_API',
     'Context',
     'Socket',
     'Frame',
